@@ -12,17 +12,26 @@ class mt_standard_deduction_indiv(Variable):
     defined_for = StateCode.MT
 
     def formula(person, period, parameters):
+        # ▸ MT legacy parameter table (only relevant pre-2024)
+        p = parameters(period).gov.states.mt.tax.income.deductions.standard
+
         filing_status = person.tax_unit(
             "state_filing_status_if_married_filing_separately_on_same_return",
             period,
         )
-        p = parameters(period).gov.states.mt.tax.income.deductions.standard
-        agi = person("mt_agi", period)
-        # standard deduction is a percentage of AGI that
-        # is bounded by a min/max by filing status.
-        floor = p.floor[filing_status]
-        cap = p.cap[filing_status]
-        uncapped_amount = p.rate * agi
-        deduction_amount = max_(min_(uncapped_amount, cap), floor)
+
+        if p.applies:
+            # ── Pre-2024 MT-specific calculation ────────────────────────────────
+            agi = person("mt_agi", period)
+            floor = p.floor[filing_status]
+            cap = p.cap[filing_status]
+            uncapped = p.rate * agi
+            deduction_amount = max_(min_(uncapped, cap), floor)
+
+        else:
+            # ── 2024-onward: apply the *federal* standard-deduction variable ──
+
+            deduction_amount = person.tax_unit("standard_deduction", period)
+
         is_head_or_spouse = person("is_tax_unit_head_or_spouse", period)
         return is_head_or_spouse * deduction_amount
